from setuptools import setup

setup(name='kd_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['kd_distributions'],
      author = 'Kaustubh Dixit',
      author_email = 'kdkishu335@gmail.com',
      zip_safe=False)
